@@ -1,6 +1,6 @@
 // STL
 #include <iostream>
-#include <algorithm> // random_shuffle, reverse, sort, ...
+#include <algorithm> 
 #include <cmath>
 // SCYTHE
 #include "mersenne.h"
@@ -12,10 +12,11 @@
 #include "stat.h" 
 #include "smath.h" 
 // R interface
-#include <R.h>           // needed to use Rprintf()
-#include <R_ext/Utils.h> // needed to allow user interrupts
+#include <R.h>           
+#include <R_ext/Utils.h> 
 #include <Rdefines.h>
 #include <Rinternals.h>
+//
 #include "cumres.h"
 #include "extra.h"
 
@@ -73,23 +74,22 @@ Matrix<double> Wscorerate_crr(const unsigned &k,
 }
 
 extern "C" {
-  void crrscoreW(const int *R, // Number of realizations
-		 const unsigned *n, // Number of individuals
+  void crrscoreW(const int *R,
+		 const unsigned *n,
      const unsigned *m,
-		 const unsigned *nd, // Number of interest events
-     const unsigned *ncom, // Number of competitive events
-     const unsigned *nc, // Number of censory times
-		 const unsigned *p, // Number of  parameters
+		 const unsigned *nd,
+     const unsigned *ncom,
+     const unsigned *nc,
+		 const unsigned *p,
      const double *G_data,
      const unsigned long *seed,
-		 const double *beta_data,  // nxp, parameter vector
-		 const double *time_data, // 
+		 const double *beta_data,
+		 const double *time_data, 
      const unsigned *index_otime_data,
-		 const unsigned *index_dtimes_data, // interest events times
-     const unsigned *index_comptimes_data, // competitive events times
-     const unsigned *index_censtimes_data, // censory times
-		 const double *X_data,  // nxp, Design matrix
-		 const double *Mt_data, // Martingale residuals
+		 const unsigned *index_dtimes_data,
+     const unsigned *index_comptimes_data,
+     const unsigned *index_censtimes_data,
+		 const double *X_data,  
 		 const unsigned *plotnum,
      const unsigned *type_test_num,
 		 double *KS,
@@ -226,7 +226,7 @@ extern "C" {
   }
  
   Matrix<double> Itprep = multCol(S_2, t(1/S_0)); 
-  Itprep = Itprep-E_2; // Martinussen & Scheike p. 184
+  Itprep = Itprep-E_2;
   Matrix<double>It=multCol(Itprep,t(dN));
   It=cumsum(It);  
   Matrix<double> Itau = It(*m-1,_); Itau.resize(*p,*p);
@@ -384,4 +384,4 @@ extern "C" {
       }
     }
 	} 
-} // extern "C"
+}
